@@ -2,8 +2,9 @@ import argparse
 import sys
 
 from libcomcat.search import search, count
-from libcomcat.utils import get_detail_data_frame, get_summary_data_frame, maketime
-from impactutils.time.ancient_time import HistoricTime
+from libcomcat.utils import (get_detail_data_frame,
+                             get_summary_data_frame,
+                             maketime)
 
 
 def get_parser():
@@ -43,13 +44,13 @@ def get_parser():
     time format (YYYY-mm-ddTHH:MM:SS, YYYY-mm-ddTHH:MM:SS.s): %(prog)s -s
     2015-01-01T00:00:00 -e 2015-01-01T01:15:00
 
-    NOTES: 
+    NOTES:
 
     Any start or end time where only date is specified (YYYY-mm-dd) will
     be translated to the beginning of that day.  Thus, a start time of
     "2015-01-01" becomes "2015-01-01T:00:00:00" and an end time of "2015-01-02"
     becomes ""2015-01-02T:00:00:00".
-    
+
     Events which do not have a value for a given field (moment tensor
     components, for example), will have the string "nan" instead.
 
@@ -58,86 +59,126 @@ def get_parser():
     meridian (i.e., lonmin=179, lonmax=-179).  The program will resolve the
     discrepancy.
 
-    When specifying the -a or -o flags, whether "preferred" or "all", 
+    When specifying the -a or -o flags, whether "preferred" or "all",
     a new column will be added for each different source and algorithm
-    used to create the moment tensor or focal mechanism.  For example, 
-    columns containing NEIC W-phase moment tensor solution information should be 
-    prepended by "us_Mww" (network_method) to distinguish them from, say "nc_mwr"
-    (Northern California regional moment tensor).  If "all" is chosen, then there
-    will be many such columns of information, each prepended with the network 
-    and method, WHERE SUCH METHOD IS AVAILABLE IN THE DATABASE.
-    
-    The ComCat API has a returned event limit of 20,000.  
-    Queries that exceed this ComCat limit ARE supported by this
-    software, by breaking up one large request into a number of
-    smaller ones.  However, large queries, when also configured to
-    retrieve moment tensor parameters, nodal plane angles, or moment
-    tensor type can take a very long time to download. This delay is 
-    caused by the fact that when this program has to retrieve moment 
-    tensor parameters, nodal plane angles, or moment tensor type, it 
-    must open a URL for EACH event and parse the data it finds.  If 
-    these parameters are not requested, then the same request will 
-    return in much less time (~10 minutes or less for a 20,000 event query).
-    Queries for all magnitude solutions will take even more time, as this
-    requires parsing an XML file for each event and extracting the magnitude
-    values and associated source and type.
-    '''
+    used to create the moment tensor or focal mechanism.  For example,
+    columns containing NEIC W-phase moment tensor solution information
+    should be prepended by "us_Mww" (network_method) to distinguish
+    them from, say "nc_mwr" (Northern California regional moment
+    tensor).  If "all" is chosen, then there will be many such columns
+    of information, each prepended with the network and method, WHERE
+    SUCH METHOD IS AVAILABLE IN THE DATABASE.
+
+    The ComCat API has a returned event limit of 20,000.  Queries that
+    exceed this ComCat limit ARE supported by this software, by
+    breaking up one large request into a number of smaller ones.
+    However, large queries, when also configured to retrieve moment
+    tensor parameters, nodal plane angles, or moment tensor type can
+    take a very long time to download. This delay is caused by the
+    fact that when this program has to retrieve moment tensor
+    parameters, nodal plane angles, or moment tensor type, it must
+    open a URL for EACH event and parse the data it finds.  If these
+    parameters are not requested, then the same request will return in
+    much less time (~10 minutes or less for a 20,000 event query).
+    Queries for all magnitude solutions will take even more time, as
+    this requires parsing an XML file for each event and extracting
+    the magnitude values and associated source and type.  '''
+
     parser = argparse.ArgumentParser(
         description=desc, formatter_class=argparse.RawDescriptionHelpFormatter)
     # positional arguments
     parser.add_argument('filename',
                         metavar='FILENAME', help='Output filename.')
     # optional arguments
-    parser.add_argument('-b', '--bounds', metavar=('lonmin', 'lonmax', 'latmin', 'latmax'),
+    helpstr = ('Bounds to constrain event search '
+               '[lonmin lonmax latmin latmax]')
+    parser.add_argument('-b', '--bounds',
+                        metavar=('lonmin', 'lonmax', 'latmin', 'latmax'),
                         dest='bounds', type=float, nargs=4,
-                        help='Bounds to constrain event search [lonmin lonmax latmin latmax]')
-    parser.add_argument('-r', '--radius', dest='radius', metavar=('lat', 'lon', 'rmax'), type=float,
-                        nargs=3, help='Search radius in KM (use instead of bounding box)')
+                        help=helpstr)
+    helpstr = 'Search radius in KM (use instead of bounding box)'
+    parser.add_argument('-r', '--radius', dest='radius',
+                        metavar=('lat', 'lon', 'rmax'),
+                        type=float, nargs=3,
+                        help=helpstr)
+    helpstr = ('Start time for search (defaults to ~30 days ago). '
+               'YYYY-mm-dd, YYYY-mm-ddTHH:MM:SS, or YYYY-mm-ddTHH:MM:SS.s')
     parser.add_argument('-s', '--start-time', dest='startTime', type=maketime,
-                        help='Start time for search (defaults to ~30 days ago).  YYYY-mm-dd, YYYY-mm-ddTHH:MM:SS, or YYYY-mm-ddTHH:MM:SS.s')
+                        help=helpstr)
+    helpstr = ('End time for search (defaults to current date/time). '
+               'YYYY-mm-dd, YYYY-mm-ddTHH:MM:SS, or YYYY-mm-ddTHH:MM:SS.s')
     parser.add_argument('-e', '--end-time', dest='endTime', type=maketime,
-                        help='End time for search (defaults to current date/time).  YYYY-mm-dd, YYYY-mm-ddTHH:MM:SS, or YYYY-mm-ddTHH:MM:SS.s')
+                        help=helpstr)
+    helpstr = ('Limit to events after specified time. YYYY-mm-dd or '
+               'YYYY-mm-ddTHH:MM:SS')
     parser.add_argument('-t', '--time-after', dest='after', type=maketime,
-                        help='Limit to events after specified time. YYYY-mm-dd or YYYY-mm-ddTHH:MM:SS')
-    parser.add_argument('-m', '--mag-range', metavar=('minmag', 'maxmag'), dest='magRange', type=float, nargs=2,
-                        help='Min/max (authoritative) magnitude to restrict search.')
+                        help=helpstr)
+    helpstr = 'Min/max (authoritative) magnitude to restrict search.'
+    parser.add_argument('-m', '--mag-range', metavar=('minmag', 'maxmag'),
+                        dest='magRange', type=float, nargs=2,
+                        help=helpstr)
+    helpstr = ('Source catalog from which products '
+               'derive (atlas, centennial, etc.)')
     parser.add_argument('-c', '--catalog', dest='catalog',
-                        help='Source catalog from which products derive (atlas, centennial, etc.)')
+                        help=helpstr)
+    helpstr = 'Source contributor (who loaded product) (us, nc, etc.)'
     parser.add_argument('-n', '--contributor', dest='contributor',
-                        help='Source contributor (who loaded product) (us, nc, etc.)')
+                        help=helpstr)
 
-    parser.add_argument('-o', '--get-moment-components', dest='getComponents', choices=['none', 'preferred', 'all'],
+    helpstr = ('Extract preferred or all moment-tensor components '
+               '(including type and derived hypocenter) where available.')
+    parser.add_argument('-o', '--get-moment-components',
+                        dest='getComponents',
+                        choices=['none', 'preferred', 'all'],
                         default='none',
-                        help='Extract preferred or all moment-tensor components (including type and derived hypocenter) where available.')
-    parser.add_argument('-a', '--get-focal-angles', dest='getAngles', choices=['none', 'preferred', 'all'],
+                        help=helpstr)
+    helpstr = ('Extract preferred or all focal-mechanism angles '
+               '(strike,dip,rake) where available.')
+    parser.add_argument('-a', '--get-focal-angles',
+                        dest='getAngles', choices=['none', 'preferred', 'all'],
                         default='none',
-                        help='Extract preferred or all focal-mechanism angles (strike,dip,rake) where available.')
+                        help=helpstr)
 
-    supphelp = """Extract moment tensor supplemental information (duration, derived origin, 
-percent double couple) when available."""
-    parser.add_argument('--get-moment-supplement', dest='getMomentSupplement', action='store_true',
-                        help=supphelp)
+    helpstr = ('Extract moment tensor supplemental information '
+               '(duration, derived origin, percent double couple) '
+               'when available.')
+    parser.add_argument('--get-moment-supplement',
+                        dest='getMomentSupplement', action='store_true',
+                        help=helpstr)
 
-    parser.add_argument('-g', '--get-all-magnitudes', dest='getAllMags', action='store_true',
-                        help='Extract all magnitudes (with sources),authoritative listed first.')
-    parser.add_argument('-f', '--format', dest='format', choices=['csv', 'tab', 'excel'], default='csv',
+    helpstr = ('Extract all magnitudes (with sources), '
+               'authoritative listed first.')
+    parser.add_argument('-g', '--get-all-magnitudes',
+                        dest='getAllMags', action='store_true',
+                        help=helpstr)
+    parser.add_argument('-f', '--format', dest='format',
+                        choices=['csv', 'tab', 'excel'], default='csv',
                         metavar='FORMAT', help='Output format.')
 
-    prodhelp = '''Limit the search to only those events containing products of type PRODUCT. 
-                  See the full list here: https://usgs.github.io/pdl/userguide/products/index.html
-'''
-    parser.add_argument('-p', '--product-type', dest='limitByProductType', metavar='PRODUCT',
-                        help=prodhelp)
-    parser.add_argument('-x', '--count', dest='getCount', action='store_true',
-                        help='Just return the number of events in search and maximum allowed.')
+    helpstr = ('Limit the search to only those events containing '
+               'products of type PRODUCT. See the full list here: '
+               'https://usgs.github.io/pdl/userguide/products/index.html')
+
+    parser.add_argument('-p', '--product-type',
+                        dest='limitByProductType', metavar='PRODUCT',
+                        help=helpstr)
+    helpstr = 'Just return the number of events in search and maximum allowed.'
+    parser.add_argument('-x', '--count', dest='getCount',
+                        action='store_true',
+                        help=helpstr)
     parser.add_argument('-v', '--verbose', dest='verbose', action='store_true',
                         help='Print progress')
-    parser.add_argument('--host', 
-                        help='Specify a different comcat *search* host than earthquake.usgs.gov.')
+    helpstr = ('Specify a different comcat *search* host than '
+               'earthquake.usgs.gov.')
+    parser.add_argument('--host',
+                        help=helpstr)
     return parser
 
 
-def main(args):
+def main():
+    parser = get_parser()
+    args = parser.parse_args()
+
     latitude = None
     longitude = None
     radiuskm = None
@@ -244,7 +285,4 @@ def main(args):
 
 
 if __name__ == '__main__':
-    parser = get_parser()
-    pargs = parser.parse_args()
-
-    main(pargs)
+    main()
